@@ -71,6 +71,16 @@ class c函数调用:
         return f'{self.函数名}({self.参数字符串})'
 
 
+class c布尔:
+    def __init__(self, v) -> None:
+        self.v = v
+
+    def __str__(self) -> str:
+        if self.v:
+            return 'true'
+        return 'false'
+
+
 class py2cpp编译器(ast.NodeVisitor):
     def __init__(self, 被编译的函数: Callable, c编译器) -> None:
         self.被编译的函数 = 被编译的函数
@@ -158,6 +168,8 @@ class py2cpp编译器(ast.NodeVisitor):
 
     def 获取值(self, value):
         if isinstance(value, ast.Constant):
+            if isinstance(value.value, bool):
+                return c布尔(value.value)
             return value.value
 
         if isinstance(value, ast.Name):
@@ -196,9 +208,9 @@ class py2cpp编译器(ast.NodeVisitor):
 
         if isinstance(value, ast.BoolOp):
             if isinstance(value.op, ast.And):
-                return '&&'.join([self.获取值(v) for v in value.values])
+                return '&&'.join([str(self.获取值(v)) for v in value.values])
             if isinstance(value.op, ast.Or):
-                return '||'.join([self.获取值(v) for v in value.values])
+                return '||'.join([str(self.获取值(v)) for v in value.values])
 
         if isinstance(value, ast.IfExp):
             test = self.获取值(value.test)
